@@ -3,16 +3,17 @@ import torch
 
 from bsrgan.utils import utils_image as util
 from bsrgan.models.network_rrdbnet import RRDBNet 
-
+from bsrgan.main_download_pretrained_models import attempt_download_from_hub
 
 class BSRGAN:
     def __init__(self, model_path):
         self.device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')
-        self.model_path = model_path
+        self.model_path = attempt_download_from_hub(model_path, hf_token=None)
         self.save = True
         self.load_model()
     
     def load_model(self):
+        
         model_name = os.path.splitext(os.path.basename(self.model_path))[0]
         if [model_name] in ['BSRGANx2']:
             sf = 2
